``saltext-formula``: Salt formula helpers
=========================================

Salt Extension providing supporting modules for formulae. Allows fast and modular layered configuration loading.

Heavily based on the excellent work done in the `template-formula <https://github.com/saltstack-formulas/template-formula>`_.

.. toctree::
  :maxdepth: 2
  :caption: Guides
  :hidden:

  topics/installation
  topics/mapstack
  topics/mapstack_details

.. toctree::
  :maxdepth: 2
  :caption: Provided Modules
  :hidden:

  ref/modules/index
  ref/wrapper/index

.. toctree::
  :maxdepth: 2
  :caption: Reference
  :hidden:

  changelog


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
